@@ -1,7 +1,7 @@
 package Data::Cmp;
 
 our $DATE = '2018-08-12'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -14,27 +14,27 @@ our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(cmp_data);
 
 # for when dealing with circular refs
-our %_seen_refaddrs;
+my %_seen_refaddrs;
 
 sub _cmp_data {
-    my ($d1, $d2) = @_;
-
-    my $cmpres;
+    my $d1 = shift;
+    my $d2 = shift;
 
     my $def1 = defined $d1;
     my $def2 = defined $d2;
-    if    ( $def1 && !$def2) { return 1 }
-    elsif (!$def1 &&  $def2) { return -1 }
-    elsif (!$def1 && !$def2) { return 0 }
+    if ($def1) {
+        return 1 if !$def2;
+    } else {
+        return $def2 ? -1 : 0;
+    }
 
     # both are defined
 
     my $reftype1 = reftype($d1);
     my $reftype2 = reftype($d2);
-    if    ( $reftype1 xor $reftype2) { return 2 }
-    elsif (!$reftype1 && !$reftype2) {
+    if (!$reftype1 && !$reftype2) {
         return $d1 cmp $d2;
-    }
+    } elsif ( $reftype1 xor $reftype2) { return 2 }
 
     # both are refs
 
@@ -84,9 +84,10 @@ sub _cmp_data {
 }
 
 sub cmp_data {
-    my ($d1, $d2) = @_;
+    my $d1 = shift;
+    my $d2 = shift;
 
-    local %_seen_refaddrs = ();
+    %_seen_refaddrs = ();
     _cmp_data($d1, $d2);
 }
 
@@ -105,7 +106,7 @@ Data::Cmp - Compare two data structures, return -1/0/1 like cmp
 
 =head1 VERSION
 
-This document describes version 0.003 of Data::Cmp (from Perl distribution Data-Cmp), released on 2018-08-12.
+This document describes version 0.004 of Data::Cmp (from Perl distribution Data-Cmp), released on 2018-08-12.
 
 =head1 SYNOPSIS
 
@@ -144,10 +145,17 @@ The following are the rules of comparison used by C<cmp_data()>:
 
 =item * Two undefs are the same
 
+ cmp_data(undef, undef); # 0
+
 =item * A defined value is greater than undef
 
+ cmp_data(undef, 0); # -1
+
 =item * Two non-reference scalars are compared string-wise using Perl's cmp
 
+ cmp_data("a", "A"); # 1
+ cmp_data(10, 9);    # -1
+
 =item * A reference and non-reference are different
 
  cmp_data([], 0); # 2
@@ -212,10 +220,10 @@ feature.
 
 =head1 SEE ALSO
 
-Other variants of Data::Cmp: L<Data::Cmp::Custom> (allows custom actions and
-comparison routines), L<Data::Cmp::Diff> (generates diff structure instead of
-just returning -1/0/1/2), L<Data::Cmp::Diff::Perl> (generates diff in the form
-of Perl code).
+Other variants of Data::Cmp: L<Data::Cmp::Numeric>, L<Data::Cmp::StrOrNumeric>,
+L<Data::Cmp::Custom> (allows custom actions and comparison routines),
+L<Data::Cmp::Diff> (generates diff structure instead of just returning
+-1/0/1/2), L<Data::Cmp::Diff::Perl> (generates diff in the form of Perl code).
 
 Modules that just return boolean result ("same or different"): L<Data::Compare>,
 L<Test::Deep::NoTest> (offers flexibility or approximate or custom comparison).
